@@ -8,9 +8,9 @@
 
 #pragma once
 
-#include<yade/lib/serialization/Serializable.hpp>
-#include<yade/lib/multimethods/Indexable.hpp>
-#include<yade/core/Dispatcher.hpp>
+#include<lib/serialization/Serializable.hpp>
+#include<lib/multimethods/Indexable.hpp>
+#include<core/Dispatcher.hpp>
 
 #define BV_FUNCTOR_CACHE
 
