@@ -6,7 +6,7 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 
-#include <yade/lib/base/Logging.hpp>
+#include <lib/base/Logging.hpp>
 #include "ThreadRunner.hpp"
 #include "ThreadWorker.hpp"
 
