@@ -1,4 +1,4 @@
-#include<yade/lib/pyutil/gil.hpp>
+#include<lib/pyutil/gil.hpp>
 void pyRunString(const std::string& cmd){
 	gilLock lock; PyRun_SimpleString(cmd.c_str());
 };
