@@ -63,8 +63,12 @@ class Gl1_Sphere : public GlShapeFunctor{
 		void initGlutGlList();
 		//Generate GlList for sliced spheres
 		void initStripedGlList();
-		//for regenerating glutSphere list if needed
+		//for regenerating glutSphere or glutTorus list if needed
 		static Real prevQuality;
+		//for regenerating glutSphere or glutTorus list if needed
+		static string prevDisplayMode;
+		//for regenerating glutTorus list if needed
+		static char prevCircleAllowedRotationAxis;
 	public:
 		virtual void go(const shared_ptr<Shape>&, const shared_ptr<State>&,bool,const GLViewInfo&);
 	YADE_CLASS_BASE_DOC_STATICATTRS(Gl1_Sphere,GlShapeFunctor,"Renders :yref:`Sphere` object",
@@ -74,6 +78,9 @@ class Gl1_Sphere : public GlShapeFunctor{
 		((bool,localSpecView,true,,"Compute specular light in local eye coordinate system."))
 		((int,glutSlices,12,(Attr::noSave | Attr::readonly),"Base number of sphere slices, multiplied by :yref:`Gl1_Sphere::quality` before use); not used with ``stripes`` (see `glut{Solid,Wire}Sphere reference <http://www.opengl.org/documentation/specs/glut/spec3/node81.html>`_)"))
 		((int,glutStacks,6,(Attr::noSave | Attr::readonly),"Base number of sphere stacks, multiplied by :yref:`Gl1_Sphere::quality` before use; not used with ``stripes`` (see `glut{Solid,Wire}Sphere reference <http://www.opengl.org/documentation/specs/glut/spec3/node81.html>`_)"))
+		((bool,circleView,false,,"For 2D simulations : display tori instead of spheres, so they will appear like circles if the viewer is looking in the right direction. In this case, remember to disable perspective by pressing \"t\"-key in the viewer."))
+		((Real,circleRelThickness,0.2,,"If :yref:`Gl1_Sphere::circleView` is enabled, this is the torus diameter relative to the sphere radius (i.e. the circle relative thickness)."))
+		((char,circleAllowedRotationAxis,'z',,"If :yref:`Gl1_Sphere::circleView` is enabled, this is the only axis ('x', 'y' or 'z') along which rotation is allowed for the 2D simulation. It allows right orientation of the tori to appear like circles in the viewer. For example, if circleAllowedRotationAxis='x' is set, blockedDOFs=\"YZ\" should also be set for all your particles."))
 	);
 	RENDERS(Sphere);
 };
