@@ -1,6 +1,6 @@
 // 2010 © Václav Šmilauer <eudoxos@arcig.cz>
 #pragma once
-#include<yade/lib/serialization/Serializable.hpp>
+#include<lib/serialization/Serializable.hpp>
 
 namespace py = boost::python;
 
