@@ -9,36 +9,36 @@
 *************************************************************************/
 #include "CapillaryTriaxialTest.hpp"
 
-#include<yade/pkg/dem/ElasticContactLaw.hpp>
-#include <yade/pkg/dem/Law2_ScGeom_CapillaryPhys_Capillarity.hpp>
-#include<yade/pkg/dem/CapillaryPhys.hpp>
-#include<yade/pkg/common/ElastMat.hpp>
-#include<yade/pkg/dem/GlobalStiffnessTimeStepper.hpp>
+#include<pkg/dem/ElasticContactLaw.hpp>
+#include <pkg/dem/Law2_ScGeom_CapillaryPhys_Capillarity.hpp>
+#include<pkg/dem/CapillaryPhys.hpp>
+#include<pkg/common/ElastMat.hpp>
+#include<pkg/dem/GlobalStiffnessTimeStepper.hpp>
 
-#include<yade/pkg/dem/TriaxialStressController.hpp>
-#include<yade/pkg/dem/TriaxialCompressionEngine.hpp>
-#include <yade/pkg/dem/TriaxialStateRecorder.hpp>
-#include <yade/pkg/dem/CapillaryStressRecorder.hpp>
+#include<pkg/dem/TriaxialStressController.hpp>
+#include<pkg/dem/TriaxialCompressionEngine.hpp>
+#include <pkg/dem/TriaxialStateRecorder.hpp>
+#include <pkg/dem/CapillaryStressRecorder.hpp>
 
-#include<yade/pkg/common/Aabb.hpp>
-#include<yade/core/Scene.hpp>
-#include<yade/pkg/common/InsertionSortCollider.hpp>
-#include<yade/core/Interaction.hpp>
-#include<yade/pkg/common/Dispatching.hpp>
-#include<yade/pkg/common/Bo1_Aabb.hpp>
+#include<pkg/common/Aabb.hpp>
+#include<core/Scene.hpp>
+#include<pkg/common/InsertionSortCollider.hpp>
+#include<core/Interaction.hpp>
+#include<pkg/common/Dispatching.hpp>
+#include<pkg/common/Bo1_Aabb.hpp>
 
-#include<yade/pkg/common/GravityEngines.hpp>
-#include<yade/pkg/dem/NewtonIntegrator.hpp>
+#include<pkg/common/GravityEngines.hpp>
+#include<pkg/dem/NewtonIntegrator.hpp>
 
-#include<yade/core/Body.hpp>
-#include<yade/pkg/common/Box.hpp>
-#include<yade/pkg/common/Sphere.hpp>
-#include<yade/pkg/dem/Ig2_Sphere_Sphere_ScGeom.hpp>
-#include<yade/pkg/dem/Ig2_Box_Sphere_ScGeom.hpp>
+#include<core/Body.hpp>
+#include<pkg/common/Box.hpp>
+#include<pkg/common/Sphere.hpp>
+#include<pkg/dem/Ig2_Sphere_Sphere_ScGeom.hpp>
+#include<pkg/dem/Ig2_Box_Sphere_ScGeom.hpp>
 
-#include<yade/pkg/common/ForceResetter.hpp>
+#include<pkg/common/ForceResetter.hpp>
 
-#include<yade/pkg/dem/Shop.hpp>
+#include<pkg/dem/Shop.hpp>
 
 #include <boost/numeric/conversion/bounds.hpp>
 #include <boost/limits.hpp>
