@@ -1,5 +1,5 @@
 // 2009 © Václav Šmilauer <eudoxos@arcig.cz> 
-#include<yade/pkg/common/Collider.hpp>
+#include<pkg/common/Collider.hpp>
 class NewtonIntegrator;
 class FlatGridCollider: public Collider{
 	struct Grid{
