@@ -13,8 +13,8 @@ class JCFpmState: public State {
 		((int,tensBreak,0,,"Number of tensile breakages. [-]"))
 		((int,shearBreak,0,,"Number of shear breakages. [-]"))
 		((int,noIniLinks,0,,"Number of initial cohesive interactions. [-]"))
-		((Real,tensBreakRel,0,,"Relative number (in [0;1], compared with :yref:noIniLinks) of tensile breakages. [-]"))
-		((Real,shearBreakRel,0,,"Relative number (in [0;1], compared with :yref:noIniLinks) of shear breakages. [-]"))
+		((Real,tensBreakRel,0,,"Relative number (in [0;1], compared with :yref:`noIniLinks<JCFpmState.noIniLinks>`) of tensile breakages. [-]"))
+		((Real,shearBreakRel,0,,"Relative number (in [0;1], compared with :yref:`noIniLinks<JCFpmState.noIniLinks>`) of shear breakages. [-]"))
 		((bool,onJoint,false,,"Identifies if the particle is on a joint surface."))
 		((int,joint,0,,"Indicates the number of joint surfaces to which the particle belongs (0-> no joint, 1->1 joint, etc..). [-]"))
 		((Vector3r,jointNormal1,Vector3r::Zero(),,"Specifies the normal direction to the joint plane 1. Rk: the ideal here would be to create a vector of vector wich size is defined by the joint integer (as much joint normals as joints). However, it needs to make the pushback function works with python since joint detection is done through a python script. lines 272 to 312 of cpp file should therefore be adapted. [-]"))
@@ -68,7 +68,7 @@ class JCFpmPhys: public NormShearPhys {
 			((Real,jointCumulativeSliding,0,,"sliding distance for particles interacting on a joint. Used, when :yref:`<Law2_ScGeom_JCFpmPhys_JointedCohesiveFrictionalPM.smoothJoint>` is true, to take into account dilatancy due to shearing. [-]"))
 			((Real,tanDilationAngle,0,,"tangent of the angle defining the dilatancy of the joint surface (auto. computed from :yref:`JCFpmMat.jointDilationAngle`). [-]"))
 			((Real,dilation,0,,"defines the normal displacement in the joint after sliding treshold. [m]"))
-			((bool,interactionIsCracked,0,,"flag for cracked interactions"))
+			((bool,isBroken,false,,"flag for broken interactions"))
 			((Real,crackJointAperture,0,,"Relative displacement between 2 spheres (in case of a crack it is equivalent of the crack aperture)"))
 			,
 			createIndex();
