@@ -40,11 +40,12 @@ class NewtonIntegrator : public FieldApplier{
 	#endif
 	// whether the cell has changed from the previous step
 	bool cellChanged;
-	bool homoDeform;
+	int homoDeform;
 	
 	// wether a body has been selected in Qt view
 	bool bodySelected;
 	Matrix3r dVelGrad;
+	Vector3r dSpin;
 
 	public:
 		bool densityScaling;// internal for density scaling
@@ -60,7 +61,7 @@ class NewtonIntegrator : public FieldApplier{
 		#endif
 		virtual void action();
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR_PY(NewtonIntegrator,GlobalEngine,"Engine integrating newtonian motion equations.",
-		((Real,damping,0.2,,"damping coefficient for Cundall's non viscous damping (see [Chareyre2005]_) [-]"))
+		((Real,damping,0.2,,"damping coefficient for Cundall's non viscous damping (see `numerical damping <https://yade-dem.org/doc/formulation.html?highlight=damping#numerical-damping>`_ and [Chareyre2005]_)"))
 		((Vector3r,gravity,Vector3r::Zero(),,"Gravitational acceleration (effectively replaces GravityEngine)."))
 		((Real,maxVelocitySq,NaN,,"store square of max. velocity, for informative purposes; computed again at every step. |yupdate|"))
 		((bool,exactAsphericalRot,true,,"Enable more exact body rotation integrator for :yref:`aspherical bodies<Body.aspherical>` *only*, using formulation from [Allen1989]_, pg. 89."))
