@@ -7,16 +7,16 @@
 *************************************************************************/
 
 #include "ThreeDTriaxialEngine.hpp"
-#include<yade/core/Scene.hpp>
-#include<yade/core/Omega.hpp>
+#include<core/Scene.hpp>
+#include<core/Omega.hpp>
 
-#include<yade/lib/base/Math.hpp>
+#include<lib/base/Math.hpp>
 #include<boost/lambda/lambda.hpp>
-#include<yade/pkg/dem/Shop.hpp>
-#include<yade/core/Interaction.hpp>
-#include<yade/pkg/common/Sphere.hpp>
-#include<yade/pkg/dem/FrictPhys.hpp>
-#include<yade/pkg/common/ElastMat.hpp>
+#include<pkg/dem/Shop.hpp>
+#include<core/Interaction.hpp>
+#include<pkg/common/Sphere.hpp>
+#include<pkg/dem/FrictPhys.hpp>
+#include<pkg/common/ElastMat.hpp>
 
 class Ip2_CohFrictMat_CohFrictMat_CohFrictPhys;
 
