@@ -43,6 +43,10 @@ CREATE_LOGGER(VTKRecorder);
 #define GET_MASK(b) b->groupMask
 #endif
 
+#include <boost/unordered_map.hpp>
+#include <boost/fusion/support/pair.hpp>
+#include <boost/fusion/include/pair.hpp>
+
 void VTKRecorder::action(){
 	vector<bool> recActive(REC_SENTINEL,false);
 	FOREACH(string& rec, recorders){
@@ -60,6 +64,7 @@ void VTKRecorder::action(){
 			recActive[REC_MATERIALID]=true;
 			recActive[REC_STRESS]=true;
 			recActive[REC_FORCE]=true;
+			recActive[REC_COORDNUMBER]=true;
 			if (scene->isPeriodic) { recActive[REC_PERICELL]=true; }
 		}
 		else if(rec=="spheres") recActive[REC_SPHERES]=true;
@@ -82,6 +87,7 @@ void VTKRecorder::action(){
 		else if(rec=="pericell" && scene->isPeriodic) recActive[REC_PERICELL]=true;
 		else if(rec=="liquidcontrol") recActive[REC_LIQ]=true;
 		else if(rec=="bstresses") recActive[REC_BSTRESS]=true;
+		else if(rec=="coordNumber") recActive[REC_COORDNUMBER]=true;
 		else LOG_ERROR("Unknown recorder named `"<<rec<<"' (supported are: all, spheres, velocity, facets, boxes, color, stress, cpm, wpm, intr, id, clumpId, materialId, jcfpm, cracks, pericell, liquidcontrol, bstresses). Ignored.");
 	}
 	// cpm needs interactions
@@ -138,10 +144,6 @@ void VTKRecorder::action(){
 	spheresId->SetName("id");
 
 #ifdef YADE_SPH
-	vtkSmartPointer<vtkDoubleArray> spheresCsSPH = vtkSmartPointer<vtkDoubleArray>::New();
-	spheresCsSPH->SetNumberOfComponents(1);
-	spheresCsSPH->SetName("SPH_Cs");
-	
 	vtkSmartPointer<vtkDoubleArray> spheresRhoSPH = vtkSmartPointer<vtkDoubleArray>::New();
 	spheresRhoSPH->SetNumberOfComponents(1);
 	spheresRhoSPH->SetName("SPH_Rho");
@@ -172,6 +174,10 @@ void VTKRecorder::action(){
 	vtkSmartPointer<vtkDoubleArray> spheresMask = vtkSmartPointer<vtkDoubleArray>::New();
 	spheresMask->SetNumberOfComponents(1);
 	spheresMask->SetName("mask");
+
+	vtkSmartPointer<vtkDoubleArray> spheresCoordNumb = vtkSmartPointer<vtkDoubleArray>::New();
+	spheresCoordNumb->SetNumberOfComponents(1);
+	spheresCoordNumb->SetName("coordNumber");
 	
 	vtkSmartPointer<vtkDoubleArray> clumpId = vtkSmartPointer<vtkDoubleArray>::New();
 	clumpId->SetNumberOfComponents(1);
@@ -267,6 +273,10 @@ void VTKRecorder::action(){
 	vtkSmartPointer<vtkDoubleArray> facetsTorqueLen = vtkSmartPointer<vtkDoubleArray>::New();
 	facetsTorqueLen->SetNumberOfComponents(1);
 	facetsTorqueLen->SetName("torqueLen");
+  
+	vtkSmartPointer<vtkDoubleArray> facetsCoordNumb = vtkSmartPointer<vtkDoubleArray>::New();
+	facetsCoordNumb->SetNumberOfComponents(1);
+	facetsCoordNumb->SetName("coordNumber");
 
 	// boxes
 	vtkSmartPointer<vtkPoints> boxesPos = vtkSmartPointer<vtkPoints>::New();
@@ -332,10 +342,10 @@ void VTKRecorder::action(){
 
 	// extras for JCFpm
 	vtkSmartPointer<vtkDoubleArray> damage = vtkSmartPointer<vtkDoubleArray>::New();
-	damage->SetNumberOfComponents(1);;
+	damage->SetNumberOfComponents(1);
 	damage->SetName("damage");
 	vtkSmartPointer<vtkDoubleArray> damageRel = vtkSmartPointer<vtkDoubleArray>::New();
-	damageRel->SetNumberOfComponents(1);;
+	damageRel->SetNumberOfComponents(1);
 	damageRel->SetName("damageRel");
 	vtkSmartPointer<vtkDoubleArray> intrIsCohesive = vtkSmartPointer<vtkDoubleArray>::New();
 	intrIsCohesive->SetNumberOfComponents(1);
@@ -382,18 +392,21 @@ void VTKRecorder::action(){
 		// holds information about cell distance between spatial and displayed position of each particle
 		vector<Vector3i> wrapCellDist; if (scene->isPeriodic){ wrapCellDist.resize(scene->bodies->size()); }
 		// save body positions, referenced by ids by vtkLine
+		
+		// map to keep real body ids and their number in a vector (intrBodyPos)
+		boost::unordered_map<Body::id_t,Body::id_t> bIdVector;
+		Body::id_t curId = 0;
 		FOREACH(const shared_ptr<Body>& b, *scene->bodies){
-			if (!b) {
-				/* must keep ids contiguous, so that position in the array corresponds to Body::id */
-				intrBodyPos->InsertNextPoint(NaN,NaN,NaN);
-				continue;
+			if (b) {
+				if(!scene->isPeriodic) {
+					intrBodyPos->InsertNextPoint(b->state->pos[0],b->state->pos[1],b->state->pos[2]);
+				} else {
+					Vector3r pos=scene->cell->wrapShearedPt(b->state->pos,wrapCellDist[b->id]);
+					intrBodyPos->InsertNextPoint(pos[0],pos[1],pos[2]);
+				}
+				bIdVector.insert (std::pair<Body::id_t,Body::id_t>(b->id,curId));
+				curId++;
 			}
-			if(!scene->isPeriodic){ intrBodyPos->InsertNextPoint(b->state->pos[0],b->state->pos[1],b->state->pos[2]); }
-			else {
-				Vector3r pos=scene->cell->wrapShearedPt(b->state->pos,wrapCellDist[b->id]);
-				intrBodyPos->InsertNextPoint(pos[0],pos[1],pos[2]);
-			}
-			assert(intrBodyPos->GetNumberOfPoints()==b->id+1);
 		}
 		FOREACH(const shared_ptr<Interaction>& I, *scene->interactions){
 			if(!I->isReal()) continue;
@@ -403,6 +416,15 @@ void VTKRecorder::action(){
 				if(!(dynamic_cast<Sphere*>(Body::byId(I->getId1())->shape.get()))) continue;
 				if(!(dynamic_cast<Sphere*>(Body::byId(I->getId2())->shape.get()))) continue;
 			}
+			
+			const auto iterId1 = bIdVector.find (I->getId1());
+			const auto iterId2 = bIdVector.find (I->getId2());
+			
+			if (iterId2 == bIdVector.end() || iterId2 == bIdVector.end()) continue;
+			
+			const auto setId1Line = iterId1->second;
+			const auto setId2Line = iterId2->second;
+			
 			/* For the periodic boundary conditions,
 				find out whether the interaction crosses the boundary of the periodic cell;
 				if it does, display the interaction on both sides of the cell, with one of the
@@ -417,8 +439,8 @@ void VTKRecorder::action(){
 			// aperiodic boundary, or interaction is inside the cell
 			if(!scene->isPeriodic || (scene->isPeriodic && (I->cellDist==wrapCellDist[I->getId2()]-wrapCellDist[I->getId1()]))){
 				vtkSmartPointer<vtkLine> line = vtkSmartPointer<vtkLine>::New();
-				line->GetPointIds()->SetId(0,I->getId1());
-				line->GetPointIds()->SetId(1,I->getId2());
+				line->GetPointIds()->SetId(0,setId1Line);
+				line->GetPointIds()->SetId(1,setId2Line);
 				intrCells->InsertNextCell(line);
 			} else {
 				assert(scene->isPeriodic);
@@ -428,10 +450,18 @@ void VTKRecorder::action(){
 				// A,B are the "fake" bodies outside the cell for id1 and id2 respectively, p1,p2 are the displayed points
 				// distance in cell units for shifting A away from p1; negated value is shift of B away from p2
 				Vector3r ptA(p01+scene->cell->hSize*(wrapCellDist[I->getId2()]-I->cellDist).cast<Real>());
+				const vtkIdType idPtA=intrBodyPos->InsertNextPoint(ptA[0],ptA[1],ptA[2]); 
+				
 				Vector3r ptB(p02+scene->cell->hSize*(wrapCellDist[I->getId1()]-I->cellDist).cast<Real>());
-				vtkIdType idPtA=intrBodyPos->InsertNextPoint(ptA[0],ptA[1],ptA[2]), idPtB=intrBodyPos->InsertNextPoint(ptB[0],ptB[1],ptB[2]);
-				vtkSmartPointer<vtkLine> line1B(vtkSmartPointer<vtkLine>::New()); line1B->GetPointIds()->SetId(0,I->getId1()); line1B->GetPointIds()->SetId(1,idPtB);
-				vtkSmartPointer<vtkLine> lineA2(vtkSmartPointer<vtkLine>::New()); lineA2->GetPointIds()->SetId(0,idPtA); lineA2->GetPointIds()->SetId(1,I->getId2());
+				const vtkIdType idPtB=intrBodyPos->InsertNextPoint(ptB[0],ptB[1],ptB[2]);
+				
+				vtkSmartPointer<vtkLine> line1B(vtkSmartPointer<vtkLine>::New());
+				line1B->GetPointIds()->SetId(0,setId2Line);
+				line1B->GetPointIds()->SetId(1,idPtB);
+				
+				vtkSmartPointer<vtkLine> lineA2(vtkSmartPointer<vtkLine>::New());
+				lineA2->GetPointIds()->SetId(0,idPtA);
+				lineA2->GetPointIds()->SetId(1,setId2Line);
 				numAddValues=2;
 			}
 			const NormShearPhys* phys = YADE_CAST<NormShearPhys*>(I->phys.get());
@@ -597,18 +627,20 @@ void VTKRecorder::action(){
 					damage->InsertNextValue(YADE_PTR_CAST<JCFpmState>(b->state)->tensBreak + YADE_PTR_CAST<JCFpmState>(b->state)->shearBreak);
 					damageRel->InsertNextValue(YADE_PTR_CAST<JCFpmState>(b->state)->tensBreakRel + YADE_PTR_CAST<JCFpmState>(b->state)->shearBreakRel);
 				}
+				if (recActive[REC_COORDNUMBER]){
+					spheresCoordNumb->InsertNextValue(b->coordNumber());
+				}
 #ifdef YADE_SPH
-				spheresCsSPH->InsertNextValue(b->Cs); 
-				spheresRhoSPH->InsertNextValue(b->rho); 
-				spheresPressSPH->InsertNextValue(b->press); 
+				spheresRhoSPH->InsertNextValue(b->state->rho); 
+				spheresPressSPH->InsertNextValue(b->state->press); 
 				spheresCoordNumbSPH->InsertNextValue(b->coordNumber()); 
 #endif
 #ifdef YADE_LIQMIGRATION
 				if (recActive[REC_LIQ]) {
-					spheresLiqVol->InsertNextValue(b->Vf);
+					spheresLiqVol->InsertNextValue(b->state->Vf);
 					const Real tmpVolIter = liqVolIterBody(b);
 					spheresLiqVolIter->InsertNextValue(tmpVolIter);
-					spheresLiqVolTotal->InsertNextValue(tmpVolIter + b->Vf);
+					spheresLiqVolTotal->InsertNextValue(tmpVolIter + b->state->Vf);
 				}
 #endif
 				if (recActive[REC_MATERIALID]) spheresMaterialId->InsertNextValue(b->material->id);
@@ -655,6 +687,9 @@ void VTKRecorder::action(){
 				}
 				if (recActive[REC_MATERIALID]) facetsMaterialId->InsertNextValue(b->material->id);
 				if (recActive[REC_MASK]) facetsMask->InsertNextValue(GET_MASK(b));
+				if (recActive[REC_COORDNUMBER]){
+					facetsCoordNumb->InsertNextValue(b->coordNumber());
+				}
 				continue;
 			}
 		}
@@ -706,6 +741,19 @@ void VTKRecorder::action(){
 						boxesStressVec->InsertNextTupleValue(s);
 						boxesStressLen->InsertNextValue(stress.norm());
 					}
+					if(recActive[REC_FORCE]){
+						scene->forces.sync();
+						const Vector3r& f = scene->forces.getForce(b->getId());
+						const Vector3r& t = scene->forces.getTorque(b->getId());
+						Real ff[3] = { (Real) f[0], (Real) f[1], (Real) f[2] };
+						Real tt[3] = { (Real) t[0], (Real) t[1], (Real) t[2] };
+						Real fn = f.norm();
+						Real tn = t.norm();
+						boxesForceVec->InsertNextTupleValue(ff);
+						boxesForceLen->InsertNextValue(fn);
+						boxesTorqueVec->InsertNextTupleValue(tt);
+						boxesTorqueLen->InsertNextValue(tn);
+					}
 					if (recActive[REC_MATERIALID]) boxesMaterialId->InsertNextValue(b->material->id);
 					if (recActive[REC_MASK]) boxesMask->InsertNextValue(GET_MASK(b));
 				}
@@ -761,7 +809,6 @@ void VTKRecorder::action(){
 			spheresUg->GetPointData()->AddArray(spheresAngVelLen);
 		}
 #ifdef YADE_SPH
-		spheresUg->GetPointData()->AddArray(spheresCsSPH);
 		spheresUg->GetPointData()->AddArray(spheresRhoSPH);
 		spheresUg->GetPointData()->AddArray(spheresPressSPH);
 		spheresUg->GetPointData()->AddArray(spheresCoordNumbSPH);
@@ -802,6 +849,7 @@ void VTKRecorder::action(){
 			spheresUg->GetPointData()->AddArray(spheresDirIII);
 		}
 		if (recActive[REC_MATERIALID]) spheresUg->GetPointData()->AddArray(spheresMaterialId);
+		if (recActive[REC_COORDNUMBER]) spheresUg->GetCellData()->AddArray(spheresCoordNumb);
 
 		#ifdef YADE_VTK_MULTIBLOCK
 		if(!multiblock)
@@ -837,6 +885,7 @@ void VTKRecorder::action(){
 		}
 		if (recActive[REC_MATERIALID]) facetsUg->GetCellData()->AddArray(facetsMaterialId);
 		if (recActive[REC_MASK]) facetsUg->GetCellData()->AddArray(facetsMask);
+		if (recActive[REC_COORDNUMBER]) facetsUg->GetCellData()->AddArray(facetsCoordNumb);
 		#ifdef YADE_VTK_MULTIBLOCK
 			if(!multiblock)
 		#endif
@@ -851,7 +900,7 @@ void VTKRecorder::action(){
 			#else
 				writer->SetInput(facetsUg);
 			#endif
-			writer->Write();	
+			writer->Write();
 		}
 	}
 	vtkSmartPointer<vtkUnstructuredGrid> boxesUg = vtkSmartPointer<vtkUnstructuredGrid>::New();
@@ -863,7 +912,7 @@ void VTKRecorder::action(){
 			boxesUg->GetCellData()->AddArray(boxesStressVec);
 			boxesUg->GetCellData()->AddArray(boxesStressLen);
 		}
-		if (recActive[REC_FACETS]){
+		if (recActive[REC_FORCE]){
 			boxesUg->GetCellData()->AddArray(boxesForceVec);
 			boxesUg->GetCellData()->AddArray(boxesForceLen);
 			boxesUg->GetCellData()->AddArray(boxesTorqueVec);
