@@ -18,12 +18,17 @@ void Ip2_ViscElCapMat_ViscElCapMat_ViscElCapPhys::go(const shared_ptr<Material>&
   // no updates of an existing contact 
   if(interaction->phys) return;
   
+  TIMING_DELTAS_START();
+  TIMING_DELTAS_CHECKPOINT("setup");
+  
   shared_ptr<ViscElCapPhys> phys (new ViscElCapPhys());
   Calculate_ViscElMat_ViscElMat_ViscElPhys(b1, b2, interaction, phys);
   
   ViscElCapMat* mat1 = static_cast<ViscElCapMat*>(b1.get());
   ViscElCapMat* mat2 = static_cast<ViscElCapMat*>(b2.get());
   
+  TIMING_DELTAS_CHECKPOINT("collide_materials");
+  
   if (mat1->Capillar and mat2->Capillar)  {
     if (mat1->Vb == mat2->Vb) {
       phys->Vb = mat1->Vb;
@@ -43,6 +48,13 @@ void Ip2_ViscElCapMat_ViscElCapMat_ViscElCapPhys::go(const shared_ptr<Material>&
       throw runtime_error("Theta should be equal for both particles!.");
     }
     
+  
+    if (mat1->dcap == mat2->dcap) {
+      phys->dcap = mat1->dcap;
+    } else {
+      throw runtime_error("Theta should be equal for both particles!.");
+    }
+    
     if (mat1->CapillarType == mat2->CapillarType and mat2->CapillarType != ""){
       
       if      (mat1->CapillarType == "Willett_numeric")  {phys->CapillarType = Willett_numeric;  phys->CapFunct = Law2_ScGeom_ViscElCapPhys_Basic::Willett_numeric_f;}
@@ -57,12 +69,17 @@ void Ip2_ViscElCapMat_ViscElCapMat_ViscElCapPhys::go(const shared_ptr<Material>&
     }
     phys->Capillar=true;
   }
-  
+  #ifdef YADE_LIQMIGRATION
+  phys->LiqMigrEnabled = mat1->LiqMigrEnabled && mat2->LiqMigrEnabled;
+  #endif
   interaction->phys = phys;
 }
 
 /* Law2_ScGeom_ViscElCapPhys_Basic */
 bool Law2_ScGeom_ViscElCapPhys_Basic::go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I) {
+  TIMING_DELTAS_START();
+  TIMING_DELTAS_CHECKPOINT("setup");
+  
   Vector3r force = Vector3r::Zero();
   
   const id_t id1 = I->getId1();
@@ -79,12 +96,16 @@ bool Law2_ScGeom_ViscElCapPhys_Basic::go(shared_ptr<IGeom>& _geom, shared_ptr<IP
    * There is only the determination of critical distance between spheres, 
    * after that the liquid bridge will be broken.
    */ 
-   
-  if (not(phys.liqBridgeCreated) and phys.Capillar and geom.penetrationDepth>=0) {
+  
+  TIMING_DELTAS_CHECKPOINT("create_liq_bridge");
+
+  if (phys.Capillar and not(phys.liqBridgeCreated) and geom.penetrationDepth>=0) {
     phys.liqBridgeCreated = true;
     phys.liqBridgeActive = false;
     #ifdef YADE_LIQMIGRATION
-    scene->addIntrs.push_back(I);
+    if (phys.LiqMigrEnabled) {
+      scene->addIntrs.push_back(I);
+    }
     #endif
     Sphere* s1=dynamic_cast<Sphere*>(bodies[id1]->shape.get());
     Sphere* s2=dynamic_cast<Sphere*>(bodies[id2]->shape.get());
@@ -97,8 +118,11 @@ bool Law2_ScGeom_ViscElCapPhys_Basic::go(shared_ptr<IGeom>& _geom, shared_ptr<IP
     }
   }
   
+  TIMING_DELTAS_CHECKPOINT("calculate_scrit");
+
   phys.sCrit = this->critDist(phys.Vb, phys.R, phys.theta);
   
+  TIMING_DELTAS_CHECKPOINT("force_calculation_liquid");
   if (geom.penetrationDepth<0) {
     if (phys.liqBridgeCreated and -geom.penetrationDepth<phys.sCrit and phys.Capillar) {
       if (not(phys.liqBridgeActive)) {
@@ -106,7 +130,32 @@ bool Law2_ScGeom_ViscElCapPhys_Basic::go(shared_ptr<IGeom>& _geom, shared_ptr<IP
         VLiqBridg += phys.Vb;
         NLiqBridg += 1;
       }
-      phys.normalForce = -phys.CapFunct(geom, phys)*geom.normal;
+      
+      const auto normalCapForceScalar = phys.CapFunct(geom, phys);
+      Real dampCapForceScalar = 0.0;
+      
+      if (phys.dcap) {
+        const State& de1 = *static_cast<State*>(bodies[id1]->state.get());
+        const State& de2 = *static_cast<State*>(bodies[id2]->state.get());
+      
+        Vector3r& shearForce = phys.shearForce;
+        if (I->isFresh(scene)) shearForce=Vector3r(0,0,0);
+        shearForce = geom.rotate(shearForce);
+        
+        const Vector3r shift2 = scene->isPeriodic ? scene->cell->intrShiftPos(I->cellDist): Vector3r::Zero(); 
+        const Vector3r shiftVel = scene->isPeriodic ? scene->cell->intrShiftVel(I->cellDist): Vector3r::Zero(); 
+      
+        const Vector3r c1x = (geom.contactPoint - de1.pos);
+        const Vector3r c2x = (geom.contactPoint - de2.pos - shift2);
+        
+        const Vector3r relativeVelocity = (de1.vel+de1.angVel.cross(c1x)) - (de2.vel+de2.angVel.cross(c2x)) + shiftVel;
+        const auto normalVelocity	= geom.normal.dot(relativeVelocity);
+        
+        dampCapForceScalar = -phys.dcap * normalVelocity;
+      }
+      
+      phys.normalForce = -(normalCapForceScalar + dampCapForceScalar)*geom.normal;
+      
       if (I->isActive) {
         addForce (id1,-phys.normalForce,scene);
         addForce (id2, phys.normalForce,scene);
@@ -122,8 +171,8 @@ bool Law2_ScGeom_ViscElCapPhys_Basic::go(shared_ptr<IGeom>& _geom, shared_ptr<IP
           phys.Vf1 = phys.Vb/2.0;
           phys.Vf2 = phys.Vb/2.0;
         }
-        const intReal B1={id1, phys.Vf1};
-        const intReal B2={id2, phys.Vf2};
+        const std::pair<id_t, Real > B1 = {id1, phys.Vf1};
+        const std::pair<id_t, Real > B2 = {id2, phys.Vf2};
         scene->delIntrs.push_back(B1);
         scene->delIntrs.push_back(B2);
       #endif
@@ -142,6 +191,7 @@ bool Law2_ScGeom_ViscElCapPhys_Basic::go(shared_ptr<IGeom>& _geom, shared_ptr<IP
     Vector3r torque1 = Vector3r::Zero();
     Vector3r torque2 = Vector3r::Zero();
     
+    TIMING_DELTAS_CHECKPOINT("force_calculation_penetr");
     if (computeForceTorqueViscEl(_geom, _phys, I, force, torque1, torque2)) {
       addForce (id1,-force,scene);
       addForce (id2, force,scene);
@@ -375,10 +425,10 @@ void LiqControl::action(){
   
   // Update volume water at each deleted interaction for each body
   for (unsigned int i=0; i<scene->delIntrs.size(); i++) {
-    shared_ptr<Body> b = Body::byId(scene->delIntrs[i].id,scene);
-    b->Vf += scene->delIntrs[i].Vol;
-    addBodyMapInt(bodyNeedUpdate, scene->delIntrs[i].id);
-    liqVolRup += scene->delIntrs[i].Vol;
+    shared_ptr<Body> b = Body::byId(scene->delIntrs[i].first,scene);
+    b->state->Vf += scene->delIntrs[i].second;
+    addBodyMapInt(bodyNeedUpdate, scene->delIntrs[i].first);
+    liqVolRup += scene->delIntrs[i].second;
   }
   scene->delIntrs.clear();
   
@@ -405,8 +455,8 @@ void LiqControl::action(){
       Real Vf1 = 0.0;
       Real Vf2 = 0.0;
       
-      if ((b1->Vmin)<b1->Vf) { Vf1 = (b1->Vf - b1->Vmin)/bI[id1]; }
-      if ((b2->Vmin)<b2->Vf) { Vf2 = (b2->Vf - b2->Vmin)/bI[id2]; }
+      if ((b1->state->Vmin)<b1->state->Vf) { Vf1 = (b1->state->Vf - b1->state->Vmin)/bI[id1]; }
+      if ((b2->state->Vmin)<b2->state->Vf) { Vf2 = (b2->state->Vf - b2->state->Vmin)/bI[id2]; }
       
       Real Vrup = Vf1+Vf2;
       
@@ -435,7 +485,7 @@ void LiqControl::action(){
   
   // Update water volume in body
   for (mapBodyReal::const_iterator it = bodyUpdateLiquid.begin(); it != bodyUpdateLiquid.end(); ++it) {
-    Body::byId(it->first)->Vf += it->second;
+    Body::byId(it->first)->state->Vf += it->second;
   }
   
   // Update contacts around body
@@ -445,11 +495,11 @@ void LiqControl::action(){
 }
 
 void LiqControl::updateLiquid(shared_ptr<Body> b){
-  if (b->Vf<=b->Vmin) {
+  if (b->state->Vf<=b->state->Vmin) {
     return;
   } else {
     // How much liquid can body share
-    const Real LiqCanBeShared = b->Vf - b->Vmin;
+    const Real LiqCanBeShared = b->state->Vf - b->state->Vmin;
     
     // Check how much liquid can accept contacts 
     Real LiqContactsAccept = 0.0;
@@ -467,11 +517,11 @@ void LiqControl::updateLiquid(shared_ptr<Body> b){
       //There are some contacts, which can be filled
       Real FillLevel = 0.0;
       if (LiqContactsAccept > LiqCanBeShared) {   // Share all available liquid from body to contacts
-        const Real LiquidWillBeShared = b->Vf - b->Vmin;
-        b->Vf = b->Vmin;
+        const Real LiquidWillBeShared = b->state->Vf - b->state->Vmin;
+        b->state->Vf = b->state->Vmin;
         FillLevel = LiquidWillBeShared/LiqContactsAccept;
       } else {                                    // Not all available liquid from body can be shared
-        b->Vf -= LiqContactsAccept;
+        b->state->Vf -= LiqContactsAccept;
         FillLevel = 1.0;
       }
       
@@ -566,9 +616,9 @@ Real liqVolIterBody (shared_ptr<Body> b) {
 Real LiqControl::liqVolBody (id_t id) const {
   Scene* scene=Omega::instance().getScene().get();
   const BodyContainer& bodies = *scene->bodies;
-  if (id >=0 and bodies[id]) {
-    if (bodies[id]->Vf > 0) {
-      return bodies[id]->Vf + liqVolIterBody(bodies[id]);
+  if (bodies[id]) {
+    if (bodies[id]->state->Vf > 0) {
+      return bodies[id]->state->Vf + liqVolIterBody(bodies[id]);
     } else {
       return liqVolIterBody(bodies[id]);
     }
@@ -582,13 +632,13 @@ Real LiqControl::totalLiqVol(int mask=0) const{
   FOREACH(const shared_ptr<Body>& b, *scene->bodies){
     if((mask>0 && (b->groupMask & mask)==0) or (!b)) continue;
     totalLiqVol += liqVolIterBody(b);
-    if (b->Vf > 0) {totalLiqVol +=b->Vf;}
+    if (b->state->Vf > 0) {totalLiqVol +=b->state->Vf;}
   }
   return totalLiqVol;
 }
 
 bool LiqControl::addLiqInter(id_t id1, id_t id2, Real liq) {
-  if (id1<0 or id2<0 or id1==id2 or liq<=0) return false;
+  if (id1==id2 or liq<=0) return false;
   
   Scene* scene=Omega::instance().getScene().get();
   shared_ptr<InteractionContainer>& intrs=scene->interactions;
