@@ -33,7 +33,6 @@
 
 namespace bfs=boost::filesystem;
 
-template<class Scalar> VECTOR3_TEMPLATE(Scalar) operator*(Scalar s, const VECTOR3_TEMPLATE(Scalar)& v) {return v*s;}
 inline Vector3i vect3rToVect3i(Vector3r vect){Vector3i newvect((int)vect[0],(int)vect[1],(int)vect[2]);return(newvect);}
 
 
@@ -618,7 +617,7 @@ void HydrodynamicsLawLBM::action()
         /*------------------------------------------------------------------*/
         /*                  GENERAL REINITIALIZATION                        */
         /*------------------------------------------------------------------*/
-        Vector3r WallBottomVel=Vector3r::Zero();//m s-1
+        // Vector3r WallBottomVel=Vector3r::Zero();//m s-1
         FmoyCur=0.;
         VmeanFluidC=0.; VmaxC=-1000000.;    VminC=1000000.;
         RhomaxC=-1000000.;  RhominC=1000000.;RhoTot=0.;
