@@ -407,7 +407,7 @@ void PeriodicFlowEngine::locateCell ( CellHandle baseCell, unsigned int& index,
 }
 
 void PeriodicFlowEngine::updateVolumes (FlowSolver& flow)
-{
+{	//FIXME: replace by the non-periodic version
         if ( debug ) cout << "Updating volumes.............." << endl;
         Real invDeltaT = 1/scene->dt;
         double newVol, dVol;
@@ -434,10 +434,15 @@ void PeriodicFlowEngine::updateVolumes (FlowSolver& flow)
                 totVol+=newVol;
                 dVol=cell->info().volumeSign * ( newVol - cell->info().volume() );
                 totDVol+=dVol;
-                epsVolMax = max ( epsVolMax, std::abs ( dVol/newVol ) );
+                if (newVol != 0) {
+                  epsVolMax = max ( epsVolMax, std::abs ( dVol/newVol ) );
+                }
                 cell->info().dv() = dVol * invDeltaT;
                 cell->info().volume() = newVol;
         }
+        for (unsigned int n=0; n<flow.imposedF.size();n++) {
+		flow.IFCells[n]->info().dv()+=flow.imposedF[n].second;
+		flow.IFCells[n]->info().Pcondition=false;}
         if ( debug ) cout << "Updated volumes, total =" <<totVol<<", dVol="<<totDVol<<" "<< totVol0<<" "<< totVol1<<endl;
 }
 
@@ -475,7 +480,6 @@ void PeriodicFlowEngine::buildTriangulation ( double pZero, FlowSolver& flow)
         if ( debug ) cout << endl << "Tesselating------" << endl << endl;
         flow.tesselation().compute();
         flow.defineFictiousCells();
-
         //FIXME: this is already done in addBoundary(?)
         boundaryConditions ( flow );
 	if ( debug ) cout << endl << "boundaryConditions------" << endl << endl;
@@ -490,12 +494,14 @@ void PeriodicFlowEngine::buildTriangulation ( double pZero, FlowSolver& flow)
 	const FiniteCellsIterator cellend=Tes.Triangulation().finite_cells_end();
         for ( FiniteCellsIterator cell=Tes.Triangulation().finite_cells_begin(); cell!=cellend; cell++ ){
                 locateCell ( cell,index,baseIndex,flow );
-		if (flow.errorCode>0) return;
+		if (flow.errorCode>0) {LOG_ERROR("problem here, flow.errorCode>0"); return;}
 		//Fill this vector than can be later used to speedup loops
 		if (!cell->info().isGhost) Tes.cellHandles[cell->info().baseIndex]=cell;
+		cell->info().id=cell->info().baseIndex;
 	}
 	Tes.cellHandles.resize(baseIndex+1);
-
+	/// Call blockHook here if defined, valid indices and ghost status are available
+	if(!blockHook.empty()){ LOG_INFO("Running blockHook: "<<blockHook); pyRunString(blockHook); }
 	if ( debug ) cout << endl << "locateCell------" << endl << endl;
         flow.computePermeability ( );
         porosity = flow.vPoralPorosity/flow.vTotalPorosity;
