@@ -23,10 +23,8 @@ from yade import utils
 
 from yade.wrapper import *
 
-try:
-	from minieigen import *
-except ImportError:
-	from miniEigen import *
+
+from minieigen import *
 
 ## compatibility hack for python 2.5 (21/8/2009)
 ## can be safely removed at some point
@@ -273,18 +271,18 @@ def regularHexa(predicate,radius,gap,**kw):
 	Created spheres will have given radius and will be separated by gap space."""
 	ret=[]
 	a=2*radius+gap
-	# thanks to Nasibeh Moradi for finding bug here:
-	# http://www.mail-archive.com/yade-users@lists.launchpad.net/msg01424.html
 	hy,hz=a*sqrt(3)/2.,a*sqrt(6)/3.
 	mn,mx=predicate.aabb()
 	dim=[mx[i]-mn[i] for i in 0,1,2]
 	if(max(dim)==float('inf')): raise ValueError("Aabb of the predicate must not be infinite (didn't you use union | instead of intersection & for unbounded predicate such as notInNotch?");
 	ii,jj,kk=[range(0,int(dim[0]/a)+1),range(0,int(dim[1]/hy)+1),range(0,int(dim[2]/hz)+1)]
 	for i,j,k in itertools.product(ii,jj,kk):
-		x,y,z=mn[0]+radius+i*a,mn[1]+radius+j*hy,mn[2]+radius+k*hz
-		if j%2==0: x+= a/2. if k%2==0 else -a/2.
-		if k%2!=0: x+=a/2.; y+=hy/2.
-		if predicate((x,y,z),radius): ret+=[utils.sphere((x,y,z),radius=radius,**kw)]
+		#Simple HCP-lattice packing
+		#http://en.wikipedia.org/wiki/Close-packing_of_equal_spheres#Simple_hcp_lattice
+		coordSph = Vector3((2*i + ((j + k) % 2 ) ),
+											(sqrt(3.)*(j + 1./3.*(k % 2))),
+											(2.*sqrt(6.)/3.*k))*(a/2.0) + mn
+		if predicate(coordSph,radius): ret+=[utils.sphere(coordSph,radius=radius,**kw)]
 	if (len(ret)==0):
 		warnings.warn('No spheres are produced by regularHexa-function',category=RuntimeWarning)
 	return ret
@@ -469,7 +467,7 @@ def randomDensePack(predicate,radius,material=-1,dim=None,cropLayers=0,rRelFuzz=
 			# upperCorner is just size ratio, if radiusMean is specified
 			upperCorner=fullDim,
 			## no need to touch any the following
-			noFiles=True,lowerCorner=[0,0,0],sigmaIsoCompaction=1e7,sigmaLateralConfinement=1e5,compactionFrictionDeg=1,StabilityCriterion=.05,strainRate=.2,thickness=-1,maxWallVelocity=.1,wallOversizeFactor=1.5,autoUnload=True,autoCompressionActivation=False).load()
+			noFiles=True,lowerCorner=[0,0,0],sigmaIsoCompaction=-1e7,sigmaLateralConfinement=-1e5,compactionFrictionDeg=1,StabilityCriterion=.05,strainRate=.2,thickness=-1,maxWallVelocity=.1,wallOversizeFactor=1.5,autoUnload=True,autoCompressionActivation=False).load()
 		while ( numpy.isnan(utils.unbalancedForce()) or utils.unbalancedForce()>0.005 ) :
 			O.run(100,True)
 		sp=SpherePack(); sp.fromSimulation()
