@@ -11,11 +11,7 @@ from yade._customConverters import *
 from yade import utils
 from yade import *
 from math import *
-
-try:
-	from minieigen import *
-except ImportError:
-	from miniEigen import *
+from minieigen import *
 
 ## TODO tests
 class TestForce(unittest.TestCase): pass
