@@ -17,11 +17,8 @@ try: # use psyco if available
 	psyco.full()
 except ImportError: pass
 
-try:
-	from minieigen import *
-except ImportError:
-	from miniEigen import *
 
+from minieigen import *
 
 # c++ implementations for performance reasons
 from yade._utils import *
@@ -220,7 +217,8 @@ def box(center,extents,orientation=Quaternion(1,0,0,0),dynamic=None,fixed=False,
 	b=Body()
 	b.shape=Box(extents=extents,color=color if color else randomColor(),wire=wire,highlight=highlight)
 	V=8*extents[0]*extents[1]*extents[2]
-	geomInert=Vector3(4*(extents[1]**2+extents[2]**2),4*(extents[0]**2+extents[2]**2),4*(extents[0]**2+extents[1]**2))
+	# I = m*dim**2/12. = (m=V) = V*(2*extent)**2/12. = V*extent**2*4/12. = V*extent**2/3.
+	geomInert=(V/3.)*Vector3(extents[1]**2+extents[2]**2,extents[0]**2+extents[2]**2,extents[0]**2+extents[1]**2)
 	_commonBodySetup(b,V,geomInert,material,pos=center,dynamic=dynamic,fixed=fixed)
 	b.state.ori=orientation
 	b.mask=mask
@@ -393,7 +391,7 @@ def tetra(vertices,strictCheck=True,dynamic=True,fixed=False,wire=True,color=Non
 def polyhedron(vertices,dynamic=True,fixed=False,wire=True,color=None,highlight=False,noBound=False,material=-1,mask=1,chain=-1):
 	"""Create polyhedron with given parameters.
 
-	:param [Vector3,Vector3,Vector3,Vector3] vertices: coordinates of vertices in the global coordinate system.
+	:param [[Vector3]] vertices: coordinates of vertices in the global coordinate system.
 
 	See :yref:`yade.utils.sphere`'s documentation for meaning of other parameters."""
 	b=Body()
@@ -534,16 +532,16 @@ def plotNumInteractionsHistogram(cutoff=0.):
 	pylab.ion()
 	pylab.show()
 
-def plotDirections(aabb=(),mask=0,bins=20,numHist=True,noShow=False):
+def plotDirections(aabb=(),mask=0,bins=20,numHist=True,noShow=False,sphSph=False):
 	"""Plot 3 histograms for distribution of interaction directions, in yz,xz and xy planes and
-	(optional but default) histogram of number of interactions per body.
+	(optional but default) histogram of number of interactions per body. If sphSph only sphere-sphere interactions are considered for the 3 directions histograms.
 
 	:returns: If *noShow* is ``False``, displays the figure and returns nothing. If *noShow*, the figure object is returned without being displayed (works the same way as :yref:`yade.plot.plot`).
 	"""
 	import pylab,math
 	from yade import utils
 	for axis in [0,1,2]:
-		d=utils.interactionAnglesHistogram(axis,mask=mask,bins=bins,aabb=aabb)
+		d=utils.interactionAnglesHistogram(axis,mask=mask,bins=bins,aabb=aabb,sphSph=sphSph)
 		fc=[0,0,0]; fc[axis]=1.
 		subp=pylab.subplot(220+axis+1,polar=True);
 		# 1.1 makes small gaps between values (but the column is a bit decentered)
@@ -1086,7 +1084,12 @@ class UnstructuredGrid:
 			e.state.pos = Vector3(0,0,0)
 			e.state.ori = Quaternion((1,0,0),0)
 			if isinstance(e.shape,Facet):
-				e.shape.vertices = [self.vertices[j] for j in c]
+				#e.shape.vertices = [self.vertices[j] for j in c]
+				vs = [Vector3(self.vertices[j]) for j in c]
+				cc = sum(vs,Vector3.Zero)/3.
+				for v in vs: v -= cc
+				e.state.pos = cc
+				e.shape.setVertices(vs)
 			elif isinstance(e.shape,Tetra):
 				e.shape.v = [self.vertices[j] for j in c]
 			else:
