@@ -11,8 +11,7 @@ es=.003
 frictionAngle=radians(35)
 density=2300
 
-params=utils.getViscoelasticFromSpheresInteraction(tc,en,es)
-defMat=O.materials.append(ViscElMat(density=density,frictionAngle=frictionAngle,**params)) # **params sets kn, cn, ks, cs
+defMat=O.materials.append(ViscElMat(density=density,frictionAngle=frictionAngle,tc=tc,en=en,et=es))
 
 
 O.dt=.1*tc # time step
@@ -43,7 +42,7 @@ O.engines=[
 ]
 
 
-O.run(25000)
+O.run(30000)
 O.wait()
 curForce = utils.sumForces(ids=floorId,direction=Vector3(0,0,1))*(-1)
 print ("Precalculated weight %f" % sphMass)
